@@ -210,11 +210,11 @@ impl PolicyPair {
     }
 }
 
-impl Into<PolicyPair> for (u64, i64) {
-    fn into(self) -> PolicyPair {
-        PolicyPair {
-            key: self.0,
-            cost: self.1,
+impl From<(u64, i64)> for PolicyPair {
+    fn from(pair: (u64, i64)) -> Self {
+        Self {
+            key: pair.0,
+            cost: pair.1,
         }
     }
 }
@@ -370,12 +370,16 @@ impl<S: BuildHasher + Clone + 'static> SampledLFU<S> {
                 let k = *k;
                 if self.metrics.is_op() {
                     self.metrics.add(MetricType::KeyUpdate, k, 1);
-                    if prev_val > cost {
-                        let diff = (prev_val - cost) as u64 - 1;
-                        self.metrics.add(MetricType::CostAdd, k, !diff);
-                    } else if cost > prev_val {
-                        let diff = (cost - prev_val) as u64;
-                        self.metrics.add(MetricType::CostAdd, k, diff);
+                    match prev_val.cmp(&cost) {
+                        std::cmp::Ordering::Less => {
+                            let diff = (cost - prev_val) as u64;
+                            self.metrics.add(MetricType::CostAdd, k, diff);
+                        }
+                        std::cmp::Ordering::Equal => {}
+                        std::cmp::Ordering::Greater => {
+                            let diff = (prev_val - cost) as u64 - 1;
+                            self.metrics.add(MetricType::CostAdd, k, !diff);
+                        }
                     }
                 }
 
